// ivao.hxx - Network interface program to send sim data onto IVAO pilot client
//
// Created by: 	J. Wojnaroski  -- castle@mminternet.com
// Date:		31 Aug 2007 
//
// 
// Adapted from original network code developed by C. Olson
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//


#ifndef _IVAO_HXX
#define _IVAO_HXX

#include <simgear/compiler.h>

#include STL_STRING

#include <FDM/flight.hxx>
#include <Main/fg_props.hxx>

#include "protocol.hxx"
#include "ivao_data.hxx"

class FGIVAO : public FGProtocol, public FGInterface {

    ivaoFGData buf;
    int length;
    
    // Sim
    SGPropertyNode_ptr p_screen;
    
    // Position on the Geod
    SGPropertyNode_ptr p_latitude;
    SGPropertyNode_ptr p_longitude;
    SGPropertyNode_ptr p_elev_node;

  // Environment
    SGPropertyNode_ptr press_node;
    
    // Orientation and state
    SGPropertyNode_ptr p_pitch;
    SGPropertyNode_ptr p_bank;
    SGPropertyNode_ptr p_heading;
    SGPropertyNode_ptr p_grndspeed;
		SGPropertyNode_ptr p_wow;

		// Radio state
		SGPropertyNode_ptr p_com1;
		SGPropertyNode_ptr p_com2;
		SGPropertyNode_ptr p_transponder;

public:

    FGIVAO();
    ~FGIVAO();

    // open hailing frequencies
    bool open();

    // process work for this port
    bool process();

    // close the channel
    bool close();

    void collect_data( const FGInterface *fdm, ivaoFGData *data );
};

#endif // _IVAO_HXX



