// ivao_data.hxx -- Define structure of IVAO pilot client - FG interface parameters
//
// Version by J. Wojnaroski for interface to IVAO pilot client
//
//
// This file defines the class/structure of the UDP packet that sends
// the simulation data created by FlightGear to the IVAO pilot client. It
// is required to "sync" the data types contained in the packet
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef _IVAO_DATA_HXX
#define _IVAO_DATA_HXX

#ifndef __cplusplus
# error This library requires C++
#endif

const int IVAO_VERSION = 1;

class ivaoFGData {

public:

    // defines msg types and contents. 
    //char	ivap_signature[7];
    unsigned short	version_id;
    unsigned short	screen_state;  // 0=windowed, 1=full screen

    // position
    double	latitude;
    double	longitude;
    double	altitude;  // height above sea level
    double	static_pressure;  // pressure at present location

    // flight parameters
    double	pitch;
    double	bank;
    double	heading;  // true heading
    double	groundspeed;
    unsigned short	wow_main;  // logical and of main gear
    
    // radio setting
    double	com_1;
    double	com_2;
    double	transponder;
};

#endif // _IVAO_DATA_HXX
